#[repr(transparent)]pub struct SessionList {
inner: TypedObjectRef<SessionList, ()>,
phantom: PhantomData<()>,
}Expand description
List of all logged in sessions.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<SessionList, ()>phantom: PhantomData<()>Implementations
Sourceimpl SessionList
impl SessionList
Sourcepub fn error(&self) -> <RefCell<Option<String>> as Property>::Value
pub fn error(&self) -> <RefCell<Option<String>> as Property>::Value
The error message, if state is set to LoadingState::Error.
Sourcepub fn settings(&self) -> <SessionListSettings as Property>::Value
pub fn settings(&self) -> <SessionListSettings as Property>::Value
The settings of the sessions.
Sourcepub fn connect_state_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_state_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the state property
Sourcepub fn connect_error_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_error_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the error property
Sourcepub fn connect_settings_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_settings_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the settings property
Sourcepub fn connect_is_empty_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_is_empty_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the is-empty property
Sourcepub fn notify_state(&self)
pub fn notify_state(&self)
Notify listeners of a change in the state property
Sourcepub fn notify_error(&self)
pub fn notify_error(&self)
Notify listeners of a change in the error property
Sourcepub fn notify_settings(&self)
pub fn notify_settings(&self)
Notify listeners of a change in the settings property
Sourcepub fn notify_is_empty(&self)
pub fn notify_is_empty(&self)
Notify listeners of a change in the is-empty property
Sourceimpl SessionList
impl SessionList
Sourcepub(crate) fn has_session_ready(&self) -> bool
pub(crate) fn has_session_ready(&self) -> bool
Whether at least one session is ready.
Sourcepub(crate) fn get(&self, session_id: &str) -> Option<SessionInfo>
pub(crate) fn get(&self, session_id: &str) -> Option<SessionInfo>
The session with the given ID, if any.
Sourcepub(crate) fn index(&self, session_id: &str) -> Option<usize>
pub(crate) fn index(&self, session_id: &str) -> Option<usize>
The index of the session with the given ID, if any.
Sourcepub(crate) fn first(&self) -> Option<SessionInfo>
pub(crate) fn first(&self) -> Option<SessionInfo>
The first session in the list, if any.
Sourcepub(crate) fn insert(&self, session: impl IsA<SessionInfo>) -> usize
pub(crate) fn insert(&self, session: impl IsA<SessionInfo>) -> usize
Insert the given session into the list.
If a session with the same ID already exists, it is replaced.
Returns the index of the session.
Sourcepub(crate) async fn restore_sessions(&self)
pub(crate) async fn restore_sessions(&self)
Restore the logged-in sessions.